summaryrefslogtreecommitdiffstats
path: root/kjsembed/qtbindings/qlistviewitem_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kjsembed/qtbindings/qlistviewitem_imp.h')
-rw-r--r--kjsembed/qtbindings/qlistviewitem_imp.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/kjsembed/qtbindings/qlistviewitem_imp.h b/kjsembed/qtbindings/qlistviewitem_imp.h
index b4c7caa8..72dfdd6e 100644
--- a/kjsembed/qtbindings/qlistviewitem_imp.h
+++ b/kjsembed/qtbindings/qlistviewitem_imp.h
@@ -10,7 +10,7 @@
#include <kjsembed/jsobjectproxy_imp.h>
#include <kjsembed/jsbindingbase.h>
-class TTQListViewItem;
+class TQListViewItem;
/**
* Namespace containing the KJSEmbed library.
@@ -26,7 +26,7 @@ namespace Bindings {
};
}
/**
* Wrapper class for TTQListViewItem methods.
*
* @author Richard Moore, rich@kde.org
*/
@@ -122,7 +122,7 @@ public:
*/
static void addBindings( KJS::ExecState *exec, KJS::Object &object );
- static TTQListViewItem *toTQListViewItem( KJS::Object &object );
+ static TQListViewItem *toTQListViewItem( KJS::Object &object );
//
// Constructors implemented by this class.
@@ -213,7 +213,7 @@ public:
virtual KJS::Value call( KJS::ExecState *exec, KJS::Object &self, const KJS::List &args );
private:
- TTQListViewItem *instance; // Temp
+ TQListViewItem *instance; // Temp
int id;
bool cons;
};
@@ -26,7 +26,7 @@ namespace Bindings {
}
/**
- * Wrapper class for TTQListViewItem methods.
+ * Wrapper class for TQListViewItem methods.
*
* @author Richard Moore, rich@kde.org